<?php  
defined('C5_EXECUTE') or die(_("Access Denied."));
class DashboardSystemEnvironmentCookiesController extends Controller {
	
	public function on_start() {

		## Setup error handling
		$this->myError = Loader::Helper('validation/error');
		
		## Setup the form
		$config = new Config();
		$pkg = Package::getByHandle("formigo_cookies_disclosure");
		$config->setPackageObject($pkg);

		$scriptEnable = $config->get('scriptenable');
		$scriptHtml = $config->get('scripthtml');
		$scriptDisclosure = $config->get('scriptdisclosure');
		$scriptPrivacyPolicy = $config->get('scriptprivacypolicy');
		$scriptPosition = $config->get('scriptposition');
		$scriptLimit = $config->get('scriptlimit');
		$scriptDuration = $config->get('scriptduration');
		$scriptMessagePosition = $config->get('scriptmessageposition');
		
		if($scriptEnable) {
			
			$scriptEnabledChecked = ' checked';
		
		} else {
			
			$scriptEnabledChecked = '';
			
		}	
		
		$this->set('scriptEnabledChecked', $scriptEnabledChecked);
		
		$defaultDisclosure = t('On 26 May 2011, the rules about cookies on websites changed. This site uses cookies. ');
		$defaultDisclosure.= t('Some of the cookies we use are essential for parts of the site to operate and have already been set. ');
		$defaultDisclosure.= t('We also use a ********** script which uses cookies. You may delete and block all cookies from this site, ');
		$defaultDisclosure.= t('but parts of the site will not work.');
		
		$this->set('defaultDisclosure',$defaultDisclosure);
		
		if(!$scriptDisclosure || $scriptDisclosure == '') {
		
			$scriptDisclosure = $defaultDisclosure;
			
		}	
		
		$this->set('scriptDisclosure', $scriptDisclosure);
		$this->set('scriptHtml', $scriptHtml);
		$this->set('scriptPrivacyPolicy', $scriptPrivacyPolicy);
		
		
		if(!$scriptPosition) {
			
			$scriptBottomChecked = ' checked="checked"';
			$scriptTopChecked = '';
			
		} else {	
			
			if($scriptPosition == 'top') {
		
				$scriptTopChecked = ' checked="checked"';
				$scriptBottomChecked = '';
			
			} else {
			
				$scriptBottomChecked = ' checked="checked"';
				$scriptTopChecked = '';
			
			}
		
		}

		$this->set('scriptTopChecked', $scriptTopChecked);
		$this->set('scriptBottomChecked', $scriptBottomChecked);	
		
		if(!$scriptMessagePosition) {
			
			$scriptMessageBottomChecked = ' checked="checked"';
			$scriptMessageTopChecked = '';
			
		} else {	
			
			if($scriptMessagePosition == 'top') {
		
				$scriptMessageTopChecked = ' checked="checked"';
				$scriptMessageBottomChecked  = '';
			
			} else {
			
				$scriptMessageBottomChecked = ' checked="checked"';
				$scriptMessageTopChecked = '';
			
			}
		
		}
		
		$this->set('scriptMessageTopChecked', $scriptMessageTopChecked);
		$this->set('scriptMessageBottomChecked', $scriptMessageBottomChecked);
		
		$this->set('scriptDisplayLimit',$this->selectDisplayLimit($scriptLimit)); 
		$this->set('scriptDisplayDuration', $this->selectDisplayDuration($scriptDuration));

	}	
	
	public function save() {
		
		if ($_POST) {
			
			## Save our config preferences checkboxes first
			$data = $_POST;
				
			if(($data['scriptdisclosure'] != '') && ($data['scriptprivacypolicy'] != 0)) {
			
				$data['scriptenable'] = isset ($_POST['scriptenable']) ? 1 : 0;
				
				$config = new Config();
				$pkg = Package::getByHandle("formigo_cookies_disclosure");
				$config->setPackageObject($pkg);

				foreach ($data as $key => $value) {

					if(($key != 'ccm-submit-button') && ($key != 'defaultdisclosure'))  {

							$config->save($key, $value);		

					}	

				}	
				
				## Done, confirm saved
				$this->redirect('dashboard/system/environment/cookies','saved');
			
			} else {
				
				if($data['scriptdisclosure'] == '') {
					
					$this->myError->add(t('Please complete the disclosure text field'));

					
				}	 
				
				if($data['scriptprivacypolicy'] == 0) {
				
					$this->myError->add(t('Please specify the location of your privacy policy'));

				}
				
				## Reset form
				$this->set('scriptDisclosure', $data['scriptdisclosure']);
				$this->set('scriptHtml', $data['scripthtml']);
			
			}					
			
		} else {
			
			## Not a request we expected but just in case
			$this->redirect('dashboard/system/environment/cookies');	
			
		}	
		
	}	
	
	public function on_before_render() {
		
		$cookiesHelp = t('<p>Disclose your site\'s use of cookies to your visitors, gain opt-in and prevent scripts you specify, from setting cookies until opt-in.<p>');
		$cookiesHelp .= t('<p style="margin-top:10px;"><strong>Enable Disclosure</strong> - Check/ncheck this box to start/stop the disclosure.</p>');	
		$cookiesHelp .= t('<p style="margin-top:10px;"><strong>HTML/Javascript</strong> - Paste scripts which set cookies and you need to control into this box, rather than the').' \'<a href="'.BASE_URL.DIR_REL.'/index.php/dashboard/system/seo/tracking_codes/" target="_blank">'.t('Tracking Codes').'</a>\' '. t('section of the Dashboard.</p>');
		$cookiesHelp .= t('<p style="margin-top:10px;"><strong>Script Position</strong> - As with the \'Tracking codes\' page, you can specify where your cookie creating javascripts should be inserted once your visitor has consented to them. Some scripts like Google Analytics are better served in the head of your page.</p>');
		$cookiesHelp .= t('<p style="margin-top:10px;"><strong>Disclosure Text</strong> - A free text box for you to make your cookies disclosure. This is shown with the \'Accept Cookies\' prompt when someone visits your site for the first time. Default text is supplied.</p>');
		$cookiesHelp .= t('<p style="margin-top:10px;"><strong>Disclosure Position</strong> - Should the disclosure appear at the top or bottom of your visitors\' screens. Useful if you have navigation that might be obstructed by the slide-in.</p>');
		$cookiesHelp .= t('<p style="margin-top:10px;"><strong>Privacy Policy</strong> - Specify the page on your site which contains your privacy policy.  This is presented with the disclosure in case your visitor requires more information about how you deal with privacy and cookies.</p>');
	
		$this->set('incontextHelp',$cookiesHelp);
		
		## Pass error object to view
		$this->set('error', $this->myError);
		
	}	
	
	public function saved() { 
		
		$this->set('message', t('Cookies Disclosure options saved'));
		$this->view();
		
	}
	
	public function view() { 
		
	}
	
	private function selectDisplayLimit($val = 0) {
		
		switch ($val) {
		
			case '0':
				$selected0 = ' selected';
				break;
			case '1':
				$selected1 = ' selected';
				break;
			case '2':
				$selected2 = ' selected';
				break;
			case '3':
				$selected3 = ' selected';
				break;			
			case '5':
				$selected5 = ' selected';
				break;
			case '10':
				$selected10 = ' selected';
				break;
			default:
				$selected0=' selected';		
				
		}	
		
		$select .= '<option value="10000"'.$selected0.'>Unlimited</option>';
		$select .= '<option value="1"'.$selected1.'>1 time</option>';
		$select .= '<option value="2"'.$selected2.'>2 times</option>';
		$select .= '<option value="3"'.$selected3.'>3 times</option>';
		$select .= '<option value="5"'.$selected5.'>5 times</option>';
		$select .= '<option value="10"'.$selected10.'>10 times</option>';
		$select .= '<option value="20"'.$selected20.'>20 times</option>';

		return $select;

	}	
	
	private function selectDisplayDuration($val = 10) {
		
		switch ($val) {
		
			case 5:
				$selected5 = ' selected';
				break;
			case 10:
				$selected10 = ' selected';
				break;
			case 15:
				$selected15 = ' selected';
				break;	
			case 20:
				$selected20 = ' selected';
				break;
			case 30:
				$selected30 = ' selected';
				break;		
			default:
				$selected10 = ' selected';
		}	
		
		$select .= '<option value="5"'.$selected5.'>5 seconds</option>';
		$select .= '<option value="10"'.$selected10.'>10 seconds</option>';
		$select .= '<option value="15"'.$selected15.'>15 seconds</option>';
		$select .= '<option value="20"'.$selected20.'>20 seconds</option>';
		$select .= '<option value="30"'.$selected30.'>30 seconds</option>';

		return $select;

	}
	
}	