<?php   
defined('C5_EXECUTE') or die("Access Denied.");
class PhotoSwipeBlockController extends BlockController {
	
	protected $btTable = 'btPhotoSwipe';
	protected $btInterfaceWidth = "550";
	protected $btInterfaceHeight = "400";


	protected $btExportFileColumns = array('fID');
	protected $btExportTables = array('btPhotoSwipe','btPhotoSwipeImg');

	public $defaultDuration = 5;	
	public $defaultFadeDuration = 2;	
	
	public $playback = "ORDER";	

	/** 
	 * Used for localization. If we want to localize the name/description we have to include this
	 */
	public function getBlockTypeDescription() {
		return t("Display a running loop of images.");
	}
	
	public function getBlockTypeName() {
		return t("Photo Swipe");
	}
	
	public function getJavaScriptStrings() {
		return array(
			'choose-file' => t('Choose Image/File'),
			'choose-min-2' => t('Please choose at least two images.'),
			'choose-fileset' => t('Please choose a file set.')
		);
	}
	
	function getFileSetName(){
		$sql = "SELECT fsName FROM FileSets WHERE fsID=".intval($this->fsID);
		$db = Loader::db();
		return $db->getOne($sql); 
	}

	function loadFileSet(){
		if (intval($this->fsID) < 1) {
			return false;
		}
        Loader::helper('concrete/file');
		Loader::model('file_attributes');
		Loader::library('file/types');
		Loader::model('file_list');
		Loader::model('file_set');
		
		$ak = FileAttributeKey::getByHandle('height');

		$fs = FileSet::getByID($this->fsID);
		$fileList = new FileList();		
		$fileList->filterBySet($fs);
		$fileList->filterByType(FileType::T_IMAGE);	
		$fileList->sortByFileSetDisplayOrder();
		
		$files = $fileList->get(1000,0);
		
		
		$image = array();
		$image['duration'] = $this->duration;
		$image['fadeDuration'] = $this->fadeDuration;
		$image['groupSet'] = 0;
		$image['url'] = '';
		
		$images = array();
		$maxHeight = 0;
		foreach ($files as $f) {
			$fp = new Permissions($f);
			if(!$fp->canRead()) { continue; }
			$image['fID'] 			= $f->getFileID();
			$image['fileName'] 		= $f->getFileName();
			$image['fullFilePath'] 	= $f->getPath();
			$image['url']			= '';
			
			// find the max height of all the images so PhotoSwipe doesn't bounce around while rotating
			$vo = $f->getAttributeValueObject($ak);
			if (is_object($vo)) {
				$image['imgHeight'] = $vo->getValue('height');
			}
			if ($maxHeight == 0 || $image['imgHeight'] > $maxHeight) {
				$maxHeight = $image['imgHeight'];
			}
			$images[] = $image;
		}
		$this->images = $images;
	
	}

	function loadImages(){
		if(intval($this->bID)==0) $this->images=array();
		$sortChoices=array('ORDER'=>'position','RANDOM-SET'=>'groupSet asc, position asc','RANDOM'=>'rand()');
		if( !array_key_exists($this->playback,$sortChoices) ) 
			$this->playback='ORDER';
		if(intval($this->bID)==0) return array();
		$sql = "SELECT * FROM btPhotoSwipeImg WHERE bID=".intval($this->bID).' ORDER BY '.$sortChoices[$this->playback];
		$db = Loader::db();
		$this->images=$db->getAll($sql); 
	}
	
	function delete(){
		$db = Loader::db();
		$db->query("DELETE FROM btPhotoSwipeImg WHERE bID=".intval($this->bID));		
		parent::delete();
	}
	
	function loadBlockInformation() {
		if ($this->fsID == 0) {
			$this->loadImages();
		} else {
			$this->loadFileSet();
		}
		$this->randomizeImages();	
		$this->set('defaultFadeDuration', $this->defaultFadeDuration);
		$this->set('defaultDuration', $this->defaultDuration);
		$this->set('fadeDuration', $this->fadeDuration);
		$this->set('duration', $this->duration);
		$this->set('minHeight', $this->minHeight);
		$this->set('fsID', $this->fsID);
		$this->set('fsName', $this->getFileSetName());
		$this->set('images', $this->images);
		$this->set('playback', $this->playback);
		$type = ($this->fsID > 0) ? 'FILESET' : 'CUSTOM';
		$this->set('type', $type);
		$this->set('bID', $this->bID);				
	}
	
	function view() {
		$this->loadBlockInformation();
		
	}

	function add() {
		$this->loadBlockInformation();
	}
	
	function edit() {
		$this->loadBlockInformation();
	}
	
	function duplicate($nbID) {
		parent::duplicate($nbID);
		$this->loadBlockInformation();
		$db = Loader::db();
		foreach($this->images as $im) {
			$db->Execute('insert into btPhotoSwipeImg (bID, fID, url, duration, fadeDuration, groupSet, position, imgHeight) values (?, ?, ?, ?, ?, ?, ?, ?)', 
				array($nbID, $im['fID'], $im['url'], $im['duration'], $im['fadeDuration'], $im['groupSet'], $im['position'], $im['imgHeight'])
			);		
		}
	}
	
	function save($data) { 

		$args['imgheight'] = isset($data['imgheight']) ? trim($data['imgheight']):'50';
		$args['imgwidth'] = isset($data['imgwidth']) ? trim($data['imgwidth']):'50';
		$args['aspectratio'] = isset($data['aspectratio']) ? trim($data['aspectratio']):'false';
		$args['checkimg'] = isset($data['checkimg']) ? trim($data['checkimg']):'true';
		$args['cdnstatus'] = isset($data['cdnstatus']) ? trim($data['cdnstatus']):'false';
		$args['autocdn'] = isset($data['autocdn']) ? trim($data['autocdn']):'false';
		$args['cdnurl'] = isset($data['cdnurl']) ? trim($data['cdnurl']):'true';
		$args['pagination'] = isset($data['pagination']) ? trim($data['pagination']):20;
		$args['crop'] = isset($data['crop']) ? trim($data['crop']):1;
		$args['n_row'] = isset($data['n_row']) ? trim($data['n_row']):20;
		$args['space'] = isset($data['space']) ? trim($data['space']):0;
		$args['mobilecache'] = isset($data['mobilecache']) ? trim($data['mobilecache']):'false';
		
		$args['preventslideshow'] = isset($data['preventslideshow']) ? trim($data['preventslideshow']):'false';
		$args['autostartslideshow'] = isset($data['autostartslideshow']) ? trim($data['autostartslideshow']):'false';
		$args['slidespeed'] = isset($data['slidespeed']) ? trim($data['slidespeed']):250;
		$args['captionandtoolbarhide'] = isset($data['captionandtoolbarhide']) ? trim($data['captionandtoolbarhide']):'false';
		$args['captionandtoolbarflipposition'] = isset($data['captionandtoolbarflipposition']) ? trim($data['captionandtoolbarflipposition']):'false';
		$args['captionandtoolbarshowemptycaptions'] = isset($data['captionandtoolbarshowemptycaptions']) ? trim($data['captionandtoolbarshowemptycaptions']):'true';
		$args['captionandtoolbaropacity'] = isset($data['captionandtoolbaropacity']) ? trim($data['captionandtoolbaropacity']):0.8;
		
		$args['slideshowdelay'] = isset($data['slideshowdelay']) ? trim($data['slideshowdelay']):3000;
		$args['imagescalemethod'] = isset($data['imagescalemethod']) ? trim($data['imagescalemethod']):'fitNoUpscale';
		$args['fadeinspeed'] = isset($data['fadeinspeed']) ? trim($data['fadeinspeed']):250;
		$args['fadeoutspeed'] = isset($data['fadeoutspeed']) ? trim($data['fadeoutspeed']):250;
		$args['doubletapspeed'] = isset($data['doubletapspeed']) ? trim($data['doubletapspeed']):300;
		$args['doubletapzoomlevel'] = isset($data['doubletapzoomlevel']) ? trim($data['doubletapzoomlevel']):2.5;
		
		$args['enabledrag'] = isset($data['enabledrag']) ? trim($data['enabledrag']):'true';
		$args['enablekeyboard'] = isset($data['enablekeyboard']) ? trim($data['enablekeyboard']):'true';
		$args['enablemousewheel'] = isset($data['enablemousewheel']) ? trim($data['enablemousewheel']):'true';
		$args['allowuserzoom'] = isset($data['allowuserzoom']) ? trim($data['allowuserzoom']):'true';
		$args['allowrotationonuserzoom'] = isset($data['allowrotationonuserzoom']) ? trim($data['allowrotationonuserzoom']):'true';
		$args['invertmousewheel'] = isset($data['invertmousewheel']) ? trim($data['invertmousewheel']):'false';
		$args['margin'] = isset($data['margin']) ? trim($data['margin']):20;
		$args['maxuserzoom'] = isset($data['maxuserzoom']) ? trim($data['maxuserzoom']):5;
		$args['minuserzoom'] = isset($data['minuserzoom']) ? trim($data['minuserzoom']):0.5;
		$args['mousewheelspeed'] = isset($data['mousewheelspeed']) ? trim($data['mousewheelspeed']):500;
		$args['nextpreviousslidespeed'] = isset($data['nextpreviousslidespeed']) ? trim($data['nextpreviousslidespeed']):0;
		
		$args['showcaption'] = isset($data['showcaption']) ? trim($data['showcaption']):'true';
		$args['mobileimgheight'] = isset($data['mobileimgheight']) ? trim($data['mobileimgheight']):'50';
		$args['mobileimgwidth'] = isset($data['mobileimgwidth']) ? trim($data['mobileimgwidth']):'50';
		$args['captionandtoolbarautohidedelay'] = isset($data['captionandtoolbarautohidedelay']) ? trim($data['captionandtoolbarautohidedelay']):'500';
		$db = Loader::db();
		
		if( $data['type'] == 'FILESET' && $data['fsID'] > 0){
			$args['fsID'] = $data['fsID'];
			$args['duration'] = $data['duration'][0];
			$args['fadeDuration'] = $data['fadeDuration'][0];

			$files = $db->getAll("SELECT fv.fID FROM FileSetFiles fsf, FileVersions fv WHERE fsf.fsID = " . $data['fsID'] .
			         " AND fsf.fID = fv.fID AND fvIsApproved = 1");
			
			//delete existing images
			$db->query("DELETE FROM btPhotoSwipeImg WHERE bID=".intval($this->bID));
		} else if( $data['type'] == 'CUSTOM' && count($data['imgFIDs']) ){
			$args['fsID'] = 0;

			//delete existing images
			$db->query("DELETE FROM btPhotoSwipeImg WHERE bID=".intval($this->bID));
			
			//loop through and add the images
			$pos=0;
			foreach($data['imgFIDs'] as $imgFID){ 
				if(intval($imgFID)==0 || $data['fileNames'][$pos]=='tempFilename') continue;
				$vals = array(intval($this->bID),intval($imgFID), trim($data['url'][$pos]),intval($data['duration'][$pos]),intval($data['fadeDuration'][$pos]),
						intval($data['groupSet'][$pos]),intval($data['imgHeight'][$pos]),$pos);
				$db->query("INSERT INTO btPhotoSwipeImg (bID,fID,url,duration,fadeDuration,groupSet,imgHeight,position) values (?,?,?,?,?,?,?,?)",$vals);
				$pos++;
			}
		}
		
		parent::save($args);
	}
	
	function randomizeImages()
	{
		if($this->playback == 'RANDOM')
		{
			shuffle($this->images);
		}
		else if($this->playback == 'RANDOM-SET')
		{
			$imageGroups=array();
			$imageGroupIds=array();
			$sortedImgs=array();
			foreach($this->images as $imgInfo){
				$imageGroups[$imgInfo['groupSet']][]=$imgInfo;
				if( !in_array($imgInfo['groupSet'],$imageGroupIds) )
					$imageGroupIds[]=$imgInfo['groupSet'];
			}
			shuffle($imageGroupIds);
			foreach($imageGroupIds as $imageGroupId){
				foreach($imageGroups[$imageGroupId] as $imgInfo)
					$sortedImgs[]=$imgInfo;
			}
			$this->images=$sortedImgs;
		}
	}
	function photoswipe_page_url() {
 $pageURL = 'http';
 if ($_SERVER["HTTPS"] == "on") {$pageURL .= "s";}
 $pageURL .= "://";
 if ($_SERVER["SERVER_PORT"] != "80") {
  $pageURL .= $_SERVER["SERVER_NAME"].":".$_SERVER["SERVER_PORT"].$_SERVER["REQUEST_URI"];
 } else {
  $pageURL .= $_SERVER["SERVER_NAME"].$_SERVER["REQUEST_URI"];
 }
 return $pageURL;
}
function removeqsvar($url, $varname) {
    list($urlpart, $qspart) = array_pad(explode('?', $url), 2, '');
    parse_str($qspart, $qsvars);
    unset($qsvars[$varname]);
    $newqs = http_build_query($qsvars);
   
    return $urlpart . '?' . $newqs;
	
}
	
}

?>
